// Copyright (C) 2020 Guido Berhoerster <guido+sievemgr@berhoerster.name>
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package main

import (
	"os"
)

func init() {
	cmdGet.Flag.StringVar(&acctName, "a", "", "Select the account")
}

var cmdGet = &command{
	UsageLine: "get [options] name",
	Run:       runGet,
}

func runGet(cmd *command, args []string) error {
	if len(args) != 1 {
		return usageError("invalid number of arguments")
	}

	scriptName := args[0]

	acct, err := getAccount(&conf, acctName)
	if err != nil {
		return err
	}

	if err := lookupHostPort(acct); err != nil {
		return err
	}

	if err := readPassword(acct); err != nil {
		return err
	}

	c, err := dialPlainAuth(acct)
	if err != nil {
		return err
	}
	defer c.Logout()

	script, err := c.GetScript(scriptName)
	if err != nil {
		return err
	}
	os.Stdout.WriteString(script)

	return nil
}
