// Copyright (C) 2020 Guido Berhoerster <guido+sievemgr@berhoerster.name>
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package main

import (
	"fmt"
	"net"
)

func init() {
	cmdInfo.Flag.StringVar(&acctName, "a", "", "Select the account")
}

var cmdInfo = &command{
	UsageLine: "info [options]",
	Run:       runInfo,
}

func runInfo(cmd *command, args []string) error {
	if len(args) != 0 {
		return usageError("invalid number of arguments")
	}

	acct, err := getAccount(&conf, acctName)
	if err != nil {
		return err
	}

	if err := lookupHostPort(acct); err != nil {
		return err
	}

	if err := readPassword(acct); err != nil {
		return err
	}

	c, err := dialPlainAuth(acct)
	if err != nil {
		return err
	}
	defer c.Logout()

	fmt.Printf("%s (%s)\n", net.JoinHostPort(acct.Host, acct.Port),
		c.Implementation())
	if c.SupportsRFC5804() {
		fmt.Println("RFC5804 supported")
	}
	if c.SupportsTLS() {
		fmt.Println("STARTTLS supported")
	}
	fmt.Printf("SASL mechanisms:\n")
	for _, m := range c.SASLMechanisms() {
		fmt.Printf("  %s\n", m)
	}
	fmt.Printf("Extensions:\n")
	for _, e := range c.Extensions() {
		fmt.Printf("  %s\n", e)
	}
	fmt.Printf("Notification methods:\n")
	for _, m := range c.NotifyMethods() {
		fmt.Printf("  %s\n", m)
	}

	return nil
}
